@@ -181,7 +181,7 @@ setMethod("dwi.smooth.ms",
                             as.integer(ngrad),#ngrad
                             as.double(lambda),#lambda
                             as.double(ws0),# wghts0 rel. weight for s0 image
-                            as.integer(mc.cores),#ncores
+#                            as.integer(mc.cores),#ncores
                             as.integer(param$ind),#ind
                             as.double(param$w),#w
                             as.integer(param$n),#n
